import { ElementRef, SimpleChanges, OnChanges, OnDestroy, DoCheck } from '@angular/core';
import { DynamicHTMLRenderer } from './renderer';
/**
 * ComponentOutlet is a directive to create dynamic component.
 *
 * Example:
 *
 * ```ts
 * @Component({
 *   selector: 'my-app',
 *   template: `
 *     <dynamic-html [content]="content"></dynamic-html>
 *   `
 * })
 * export class AppComponent {
 *   content = `
 *   <article>
 *     <h1>Awesome Document</h1>
 *     <div>
 *       <p>bla bla bla</p>
 *       <my-button></my-button>
 *     </div>
 *   </article>
 *   `;
 * }
 * ```
 *
 */
export declare class DynamicHTMLComponent implements DoCheck, OnChanges, OnDestroy {
    private renderer;
    private elementRef;
    content: string;
    private ref;
    constructor(renderer: DynamicHTMLRenderer, elementRef: ElementRef);
    ngOnChanges(_: SimpleChanges): void;
    ngDoCheck(): void;
    ngOnDestroy(): void;
}
